% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/Diversity.R
\name{resampleDiversity}
\alias{resampleDiversity}
\title{Generate a clonal diversity index curve}
\usage{
resampleDiversity(data, group, clone = "CLONE", min_q = 0, max_q = 32,
  step_q = 0.05, min_n = 10, max_n = NULL, replace = FALSE, ci = 0.95,
  nboot = 2000)
}
\arguments{
\item{data}{data.frame with Change-O style columns containing clonal assignments.}

\item{group}{name of the \code{data} column containing group identifiers.}

\item{clone}{name of the \code{data} column containing clone identifiers.}

\item{min_q}{minimum value of \eqn{q}.}

\item{max_q}{maximum value of \eqn{q}.}

\item{step_q}{value by which to increment \eqn{q}.}

\item{min_n}{minimum number of observations to sample.
A group with less observations than the minimum is excluded.}

\item{max_n}{maximum number of observations to sample. If \code{NULL} the maximum
if automatically determined from the size of the largest group.}

\item{replace}{if \code{TRUE} resample with replacement; if \code{FALSE} resample
without replacement.}

\item{ci}{confidence interval to calculate; the value must be between 0 and 1.}

\item{nboot}{number of bootstrap realizations to generate.}
}
\value{
A \code{\link{DiversityCurve}} object summarizing the diversity scores.
}
\description{
\code{resampleDiversity} divides a set of clones by a group annotation,
uniformly resamples the sequences from each group, and calculates diversity
scores (\eqn{D}) over an interval of diversity orders (\eqn{q}).
}
\details{
Clonal diversity is calculated using the generalized diversity index proposed by
Hill (Hill, 1973). See \code{\link{calcDiversity}} for further details.

To generate a smooth curve, \eqn{D} is calculated for each value of \eqn{q} from
\code{min_q} to \code{max_q} incremented by \code{step_q}; \eqn{D} at \eqn{q=1} is
estimated by \eqn{D} at \eqn{q=0.9999}. Variability in total sequence counts across
unique values in the \code{group} column is corrected using repeated sampling
\code{nboot} times. Each resampling realization is fixed to a uniform count for each
group, determined by either the value of \code{max_n} or the minimum number of
sequences among all groups when \code{max_n=NULL}.

The diversity index (\eqn{D}) for each group is the median value of over all resampling
realizations, with the confidence interval estimate derived via the percentile method.
}
\examples{
# Load example data
file <- system.file("extdata", "changeo_demo.tab", package="alakazam")
df <- readChangeoDb(file)

# All groups pass default minimum sampling threshold of 10 sequences
# With replacement
resampleDiversity(df, "SAMPLE", step_q=1, max_q=10, nboot=100, replace=TRUE)
# Without replacement
resampleDiversity(df, "SAMPLE", step_q=1, max_q=10, nboot=100, replace=FALSE)

# Increasing threshold results in exclusion of small groups and a warning message
resampleDiversity(df, "ISOTYPE", min_n=40, step_q=1, max_q=10, nboot=100)
}
\references{
\enumerate{
  \item  Hill M. Diversity and evenness: a unifying notation and its consequences.
           Ecology. 1973 54(2):427-32.
  \item  Wu Y-CB, et al. Influence of seasonal exposure to grass pollen on local and
           peripheral blood IgE repertoires in patients with allergic rhinitis.
           J Allergy Clin Immunol. 2014 134(3):604-12.
}
}
\seealso{
See \code{\link{calcDiversity}} for the basic calculation and
          \code{\link{DiversityCurve}} for the return object.
          See \code{\link{testDiversity}} for significance testing.
}

