% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/Diversity.R
\name{testDiversity}
\alias{testDiversity}
\title{Pairwise test of the diversity index}
\usage{
testDiversity(data, q, group, clone = "CLONE", min_n = 10, max_n = NULL,
  nboot = 2000)
}
\arguments{
\item{data}{data.frame with Change-O style columns containing clonal assignments.}

\item{q}{diversity order to test.}

\item{group}{name of the \code{data} column containing group identifiers.}

\item{clone}{name of the \code{data} column containing clone identifiers.}

\item{min_n}{minimum number of observations to sample.
A group with less observations than the minimum is excluded.}

\item{max_n}{maximum number of observations to sample. If \code{NULL} the maximum
if automatically determined from the size of the largest group.}

\item{nboot}{number of bootstrap realizations to perform.}
}
\value{
A \code{\link{DiversityTest}} object containing p-values and summary statistics.
}
\description{
\code{testDiversity} performs pairwise significance tests of the diversity index
(\eqn{D}) at a given diversity order (\eqn{q}) for a set of annotation groups via
bootstrapping.
}
\details{
Clonal diversity is calculated using the generalized diversity index proposed by
Hill (Hill, 1973). See \code{\link{calcDiversity}} for further details.

Variability in total sequence counts across unique values in the \code{group} column is
corrected using repeated subsampling with replacement (bootstrapping) \code{nboot} times.
Each bootstrap realization is fixed to a uniform count for each group, determined by
either the value of \code{max_n} or the minimum number of sequences among all groups when
\code{max_n=NULL}. The diversity index estimate (\eqn{D}) for each group is the median value
of over all bootstrap realizations.

Significance of the difference in diversity index (\eqn{D}) between groups is tested by
constructing a bootstrap delta distribution for each pair of unique values in the
\code{group} column. The bootstrap delta distribution is built by subtracting the diversity
index \eqn{Da} in \eqn{group-a} from the corresponding value \eqn{Db} in \eqn{group-b},
for all bootstrap realizations, yeilding a distribution of \code{nboot} total deltas; where
\eqn{group-a} is the group with the greater median \eqn{D}. The p-value for hypothesis
\eqn{Da  !=  Db} is the value of \eqn{P(0)} from the empirical cumulative distribution function of the
bootstrap delta distribution, multipled by 2 for the two-tailed correction.
}
\note{
This method may inflate statistical significance when clone sizes are uniformly small,
such as when most clones sizes are 1, sample size is small, and \code{max_n} is near
the total count of the smallest data group. Use caution when interpreting the results
in such cases. We are currently investigating this potential problem.
}
\examples{
# Load example data
file <- system.file("extdata", "changeo_demo.tab", package="alakazam")
df <- readChangeoDb(file)

# Groups under the size threshold are excluded and a warning message is issued.
testDiversity(df, "SAMPLE", q=0, min_n=30, nboot=1000)
}
\references{
\enumerate{
  \item  Hill M. Diversity and evenness: a unifying notation and its consequences.
           Ecology. 1973 54(2):427-32.
  \item  Wu Y-CB, et al. Influence of seasonal exposure to grass pollen on local and
           peripheral blood IgE repertoires in patients with allergic rhinitis.
           J Allergy Clin Immunol. 2014 134(3):604-12.
}
}
\seealso{
See \code{\link{calcDiversity}} for the basic calculation and
          \code{\link{DiversityTest}} for the return object.
          See \code{\link{resampleDiversity}} for curve generation.
          See \code{\link{ecdf}} for computation of the empirical cumulative
          distribution function.
}

